==> kubernetes-model-core-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/LoadBalancerIngressFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerIngressFluentImpl<A extends LoadBalancerIngressFluent<A>> extends BaseFluent<A> implements LoadBalancerIngressFluent<A>{
  public LoadBalancerIngressFluentImpl() {
  }
  public LoadBalancerIngressFluentImpl(LoadBalancerIngress instance) {
    this.withHostname(instance.getHostname()); 
    this.withIp(instance.getIp()); 
    this.withPorts(instance.getPorts()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String hostname;
  private String ip;
  private ArrayList<PortStatusBuilder> ports = new ArrayList<PortStatusBuilder>();
  private Map<String,Object> additionalProperties;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIp() {
    return this.ip;
  }
  public A withIp(String ip) {
    this.ip=ip; return (A) this;
  }
  public Boolean hasIp() {
    return this.ip != null;
  }
  public A addToPorts(Integer index,PortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").add(index >= 0 ? index : _visitables.get("ports").size(), builder);this.ports.add(index >= 0 ? index : ports.size(), builder); return (A)this;
  }
  public A setToPorts(Integer index,PortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    PortStatusBuilder builder = new PortStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("ports").size()) { _visitables.get("ports").add(builder); } else { _visitables.get("ports").set(index, builder);}
    if (index < 0 || index >= ports.size()) { ports.add(builder); } else { ports.set(index, builder);}
     return (A)this;
  }
  public A addToPorts(io.fabric8.kubernetes.api.model.PortStatus... items) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  public A addAllToPorts(Collection<PortStatus> items) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  public A removeFromPorts(io.fabric8.kubernetes.api.model.PortStatus... items) {
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").remove(builder);if (this.ports != null) {this.ports.remove(builder);}} return (A)this;
  }
  public A removeAllFromPorts(Collection<PortStatus> items) {
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").remove(builder);if (this.ports != null) {this.ports.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPorts(Predicate<PortStatusBuilder> predicate) {
    if (ports == null) return (A) this;
    final Iterator<PortStatusBuilder> each = ports.iterator();
    final List visitables = _visitables.get("ports");
    while (each.hasNext()) {
      PortStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPorts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PortStatus> getPorts() {
    return ports != null ? build(ports) : null;
  }
  public List<PortStatus> buildPorts() {
    return ports != null ? build(ports) : null;
  }
  public PortStatus buildPort(Integer index) {
    return this.ports.get(index).build();
  }
  public PortStatus buildFirstPort() {
    return this.ports.get(0).build();
  }
  public PortStatus buildLastPort() {
    return this.ports.get(ports.size() - 1).build();
  }
  public PortStatus buildMatchingPort(Predicate<PortStatusBuilder> predicate) {
    for (PortStatusBuilder item: ports) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingPort(Predicate<PortStatusBuilder> predicate) {
    for (PortStatusBuilder item: ports) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPorts(List<PortStatus> ports) {
    if (this.ports != null) { _visitables.get("ports").removeAll(this.ports);}
    if (ports != null) {this.ports = new ArrayList(); for (PortStatus item : ports){this.addToPorts(item);}} else { this.ports = null;} return (A) this;
  }
  public A withPorts(io.fabric8.kubernetes.api.model.PortStatus... ports) {
    if (this.ports != null) {this.ports.clear();}
    if (ports != null) {for (PortStatus item :ports){ this.addToPorts(item);}} return (A) this;
  }
  public Boolean hasPorts() {
    return ports != null && !ports.isEmpty();
  }
  public A addNewPort(String error,Integer port,String protocol) {
    return (A)addToPorts(new PortStatus(error, port, protocol));
  }
  public LoadBalancerIngressFluent.PortsNested<A> addNewPort() {
    return new LoadBalancerIngressFluentImpl.PortsNestedImpl();
  }
  public LoadBalancerIngressFluent.PortsNested<A> addNewPortLike(PortStatus item) {
    return new LoadBalancerIngressFluentImpl.PortsNestedImpl(-1, item);
  }
  public LoadBalancerIngressFluent.PortsNested<A> setNewPortLike(Integer index,PortStatus item) {
    return new LoadBalancerIngressFluentImpl.PortsNestedImpl(index, item);
  }
  public LoadBalancerIngressFluent.PortsNested<A> editPort(Integer index) {
    if (ports.size() <= index) throw new RuntimeException("Can't edit ports. Index exceeds size.");
    return setNewPortLike(index, buildPort(index));
  }
  public LoadBalancerIngressFluent.PortsNested<A> editFirstPort() {
    if (ports.size() == 0) throw new RuntimeException("Can't edit first ports. The list is empty.");
    return setNewPortLike(0, buildPort(0));
  }
  public LoadBalancerIngressFluent.PortsNested<A> editLastPort() {
    int index = ports.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last ports. The list is empty.");
    return setNewPortLike(index, buildPort(index));
  }
  public LoadBalancerIngressFluent.PortsNested<A> editMatchingPort(Predicate<PortStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<ports.size();i++) { 
    if (predicate.test(ports.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching ports. No match found.");
    return setNewPortLike(index, buildPort(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerIngressFluentImpl that = (LoadBalancerIngressFluentImpl) o;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (ip != null ? !ip.equals(that.ip) :that.ip != null) return false;
    if (ports != null ? !ports.equals(that.ports) :that.ports != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  ip,  ports,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ip != null) { sb.append("ip:"); sb.append(ip + ","); }
    if (ports != null && !ports.isEmpty()) { sb.append("ports:"); sb.append(ports + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PortsNestedImpl<N> extends PortStatusFluentImpl<LoadBalancerIngressFluent.PortsNested<N>> implements LoadBalancerIngressFluent.PortsNested<N>,Nested<N>{
    PortsNestedImpl(Integer index,PortStatus item) {
      this.index = index;
      this.builder = new PortStatusBuilder(this, item);
    }
    PortsNestedImpl() {
      this.index = -1;
      this.builder = new PortStatusBuilder(this);
    }
    PortStatusBuilder builder;
    Integer index;
    public N and() {
      return (N) LoadBalancerIngressFluentImpl.this.setToPorts(index,builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/LoadBalancerIngressFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerIngressFluentImpl<A extends LoadBalancerIngressFluent<A>> extends BaseFluent<A> implements LoadBalancerIngressFluent<A>{
  public LoadBalancerIngressFluentImpl() {
  }
  public LoadBalancerIngressFluentImpl(LoadBalancerIngress instance) {
    if (instance != null) {
      this.withHostname(instance.getHostname());
      this.withIp(instance.getIp());
      this.withPorts(instance.getPorts());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String hostname;
  private String ip;
  private ArrayList<PortStatusBuilder> ports = new ArrayList<PortStatusBuilder>();
  private Map<String,Object> additionalProperties;
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIp() {
    return this.ip;
  }
  public A withIp(String ip) {
    this.ip=ip; return (A) this;
  }
  public Boolean hasIp() {
    return this.ip != null;
  }
  public A addToPorts(int index,PortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    PortStatusBuilder builder = new PortStatusBuilder(item);
    if (index < 0 || index >= ports.size()) { _visitables.get("ports").add(builder); ports.add(builder); } else { _visitables.get("ports").add(index, builder); ports.add(index, builder);}
    return (A)this;
  }
  public A setToPorts(int index,PortStatus item) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    PortStatusBuilder builder = new PortStatusBuilder(item);
    if (index < 0 || index >= ports.size()) { _visitables.get("ports").add(builder); ports.add(builder); } else { _visitables.get("ports").set(index, builder); ports.set(index, builder);}
    return (A)this;
  }
  public A addToPorts(io.fabric8.kubernetes.api.model.PortStatus... items) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  public A addAllToPorts(Collection<PortStatus> items) {
    if (this.ports == null) {this.ports = new ArrayList<PortStatusBuilder>();}
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").add(builder);this.ports.add(builder);} return (A)this;
  }
  public A removeFromPorts(io.fabric8.kubernetes.api.model.PortStatus... items) {
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").remove(builder);if (this.ports != null) {this.ports.remove(builder);}} return (A)this;
  }
  public A removeAllFromPorts(Collection<PortStatus> items) {
    for (PortStatus item : items) {PortStatusBuilder builder = new PortStatusBuilder(item);_visitables.get("ports").remove(builder);if (this.ports != null) {this.ports.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPorts(Predicate<PortStatusBuilder> predicate) {
    if (ports == null) return (A) this;
    final Iterator<PortStatusBuilder> each = ports.iterator();
    final List visitables = _visitables.get("ports");
    while (each.hasNext()) {
      PortStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPorts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PortStatus> getPorts() {
    return ports != null ? build(ports) : null;
  }
  public List<PortStatus> buildPorts() {
    return ports != null ? build(ports) : null;
  }
  public PortStatus buildPort(int index) {
    return this.ports.get(index).build();
  }
  public PortStatus buildFirstPort() {
    return this.ports.get(0).build();
  }
  public PortStatus buildLastPort() {
    return this.ports.get(ports.size() - 1).build();
  }
  public PortStatus buildMatchingPort(Predicate<PortStatusBuilder> predicate) {
    for (PortStatusBuilder item: ports) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingPort(Predicate<PortStatusBuilder> predicate) {
    for (PortStatusBuilder item: ports) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPorts(List<PortStatus> ports) {
    if (this.ports != null) { _visitables.get("ports").clear();}
    if (ports != null) {this.ports = new ArrayList(); for (PortStatus item : ports){this.addToPorts(item);}} else { this.ports = null;} return (A) this;
  }
  public A withPorts(io.fabric8.kubernetes.api.model.PortStatus... ports) {
    if (this.ports != null) {this.ports.clear(); _visitables.remove("ports"); }
    if (ports != null) {for (PortStatus item :ports){ this.addToPorts(item);}} return (A) this;
  }
  public Boolean hasPorts() {
    return ports != null && !ports.isEmpty();
  }
  public A addNewPort(String error,Integer port,String protocol) {
    return (A)addToPorts(new PortStatus(error, port, protocol));
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> addNewPort() {
    return new LoadBalancerIngressFluentImpl.PortsNestedImpl();
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> addNewPortLike(PortStatus item) {
    return new LoadBalancerIngressFluentImpl.PortsNestedImpl(-1, item);
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> setNewPortLike(int index,PortStatus item) {
    return new LoadBalancerIngressFluentImpl.PortsNestedImpl(index, item);
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> editPort(int index) {
    if (ports.size() <= index) throw new RuntimeException("Can't edit ports. Index exceeds size.");
    return setNewPortLike(index, buildPort(index));
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> editFirstPort() {
    if (ports.size() == 0) throw new RuntimeException("Can't edit first ports. The list is empty.");
    return setNewPortLike(0, buildPort(0));
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> editLastPort() {
    int index = ports.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last ports. The list is empty.");
    return setNewPortLike(index, buildPort(index));
  }
  public LoadBalancerIngressFluentImpl.PortsNested<A> editMatchingPort(Predicate<PortStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<ports.size();i++) { 
    if (predicate.test(ports.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching ports. No match found.");
    return setNewPortLike(index, buildPort(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerIngressFluentImpl that = (LoadBalancerIngressFluentImpl) o;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(ip, that.ip)) return false;

    if (!java.util.Objects.equals(ports, that.ports)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  ip,  ports,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ip != null) { sb.append("ip:"); sb.append(ip + ","); }
    if (ports != null && !ports.isEmpty()) { sb.append("ports:"); sb.append(ports + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PortsNestedImpl<N> extends PortStatusFluentImpl<LoadBalancerIngressFluentImpl.PortsNested<N>> implements LoadBalancerIngressFluentImpl.PortsNested<N>,Nested<N>{
    PortsNestedImpl(int index,PortStatus item) {
      this.index = index;
      this.builder = new PortStatusBuilder(this, item);
    }
    PortsNestedImpl() {
      this.index = -1;
      this.builder = new PortStatusBuilder(this);
    }
    PortStatusBuilder builder;
    int index;
    public N and() {
      return (N) LoadBalancerIngressFluentImpl.this.setToPorts(index,builder.build());
    }
    public N endPort() {
      return and();
    }
    
  }
  
}
